changeset 3121:a89747c41077

* cdl/phy_eth_drivers.cdl: Use CYGHWR_DEVS_ETH_PHY_DP8384X name instead CYGHWR_DEVS_ETH_PHY_DP83847 * src/DP83847.c: Renamed stat() function, add new PHY DP83848C Update due renaming CYGHWR_DEVS_ETH_PHY_DP83847 to CYGHWR_DEVS_ETH_PHY_DP8384X. [ Bugzilla 1001235 ]
author sergeig
date Sat, 23 Jul 2011 17:17:46 +0000
parents 6724f8254bcb
children b6126f4db3ef
files packages/devs/eth/phy/current/ChangeLog packages/devs/eth/phy/current/cdl/phy_eth_drivers.cdl packages/devs/eth/phy/current/src/DP83847.c
diffstat 3 files changed, 16 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/packages/devs/eth/phy/current/ChangeLog
+++ b/packages/devs/eth/phy/current/ChangeLog
@@ -1,3 +1,11 @@
+2011-07-22  Christophe Coutand  <ecos@hotmail.co.uk>  and sergeig
+
+	* cdl/phy_eth_drivers.cdl: Use CYGHWR_DEVS_ETH_PHY_DP8384X name
+	instead CYGHWR_DEVS_ETH_PHY_DP83847
+	* src/DP83847.c: Renamed stat() function, add new PHY DP83848C
+	Update due renaming CYGHWR_DEVS_ETH_PHY_DP83847 to
+	CYGHWR_DEVS_ETH_PHY_DP8384X. [ Bugzilla 1001235 ]
+
 2011-07-02  Ilija Kocho  <ilijak@siva.com.mk>
 
 	* src/KSZ8041.c: More silicon revisions.  [Bugzilla 1001274]
--- a/packages/devs/eth/phy/current/cdl/phy_eth_drivers.cdl
+++ b/packages/devs/eth/phy/current/cdl/phy_eth_drivers.cdl
@@ -78,13 +78,13 @@ cdl_package CYGPKG_DEVS_ETH_PHY {
            before giving up and declaring the link dead/missing."
     }
 
-    cdl_option CYGHWR_DEVS_ETH_PHY_DP83847 {
-        display       "NSDP83847"
+    cdl_option CYGHWR_DEVS_ETH_PHY_DP8384X {
+        display       "NSDP8384X"
         flavor        bool
         default_value 0
         compile       -library=libextras.a DP83847.c
         description "
-          Include support for National Semiconductor DP83847 DsPHYTER II"
+          Include support for National Semiconductor DP8384X DsPHYTER II"
     }
 
     cdl_option CYGHWR_DEVS_ETH_PHY_AM79C874 {
--- a/packages/devs/eth/phy/current/src/DP83847.c
+++ b/packages/devs/eth/phy/current/src/DP83847.c
@@ -40,10 +40,10 @@
 //#####DESCRIPTIONBEGIN####
 //
 // Author(s):    gthomas
-// Contributors: 
+// Contributors: ccoutand
 // Date:         2003-08-01
 // Purpose:      
 // Description:  Support for ethernet NS DP83847 PHY
 //              
 //
 //####DESCRIPTIONEND####
@@ -63,7 +63,7 @@
 #include <cyg/io/eth_phy.h>
 #include <cyg/io/eth_phy_dev.h>
 
-static bool dp83847_stat(eth_phy_access_t *f, int *state)
+static bool dp8384x_stat(eth_phy_access_t *f, int *state)
 {
     unsigned short phy_state;
     int tries;
@@ -94,4 +94,5 @@ static bool dp83847_stat(eth_phy_access_
     return false;
 }
 
-_eth_phy_dev("National Semiconductor DP83847", 0x20005c30, dp83847_stat)
+_eth_phy_dev("National Semiconductor DP83847", 0x20005c30, dp8384x_stat)
+_eth_phy_dev("National Semiconductor DP83848C", 0x20005c90, dp8384x_stat)
@@ -40,10 +40,10 @@
 // Date:         2003-08-01
 // Purpose:      
-// Description:  Support for ethernet NS DP83847 PHY
+// Description:  Support for ethernet NS DP8384X PHY
 //              
 //